@@ -17,6 +17,19 @@ welcome<-function(){
     cat("\n")
 }
 ##############################################################
+result=NULL
+if(length(object$tau)>1){
+for(ii in 1:length(object$tau)){
+CredInt = apply(object$beta[,,ii], 2, quantile, c(0.025, 0.975))
+#Estimate= apply(object$beta[,,ii], 2, mean)
+Estimate= object$coefficients[,ii]
+
+
+for(i in 1:length(CredInt [1,])){
+if (sign(CredInt [1,i])==-1 & sign (CredInt [2,i])==1)  Estimate [i]=0 
+}
+result= cbind(result,Estimate)}
+}else{
 CredInt = apply(object$beta, 2, quantile, c(0.025, 0.975))
 Estimate= coef(object)
 
@@ -24,7 +37,12 @@ for(i in 1:length(CredInt [1,])){
 if (sign(CredInt [1,i])==-1 & sign (CredInt [2,i])==1)  Estimate [i]=0 
 }
 result= cbind(Estimate)
-welcome()
-    result
 
 }
+
+welcome()
+taulabs <- paste("tau=", format(round(object$tau, 3)))
+dimnames(result) <- list(dimnames(object$beta)[[2]], taulabs)
+rownames(result)=rownames(coef(object))
+ result
+}
\ No newline at end of file
